@@ -1161,3 +1161,55 @@ def partition_dict(items, key):
     left = collections.OrderedDict(itertools.takewhile(unmatched, items_iter))
     right = collections.OrderedDict(items_iter)
     return left, item, right
+
+
+def ensure_unique(iterable, key=lambda x: x):
+    """
+    Wrap an iterable to raise a ValueError if non-unique values are encountered.
+
+    >>> from more_itertools import consume
+    >>> list(ensure_unique('abc'))
+    ['a', 'b', 'c']
+    >>> consume(ensure_unique('abca'))
+    Traceback (most recent call last):
+    ...
+    ValueError: Duplicate element 'a' encountered.
+    """
+    seen = set()
+    seen_add = seen.add
+    for element in iterable:
+        k = key(element)
+        if k in seen:
+            raise ValueError(f"Duplicate element {element!r} encountered.")
+        seen_add(k)
+        yield element
+
+
+def accumulate(increments):
+    """
+    Accumulate values in the iterable into a new iterable
+    of the same length.
+
+    >>> list(accumulate([1, 2, 3]))
+    [1, 3, 6]
+    >>> list(accumulate([0.5, -1, 20]))
+    [0.5, -0.5, 19.5]
+    >>> list(accumulate([]))
+    []
+    >>> list(accumulate([42]))
+    [42]
+
+    Accepts any objects that are summable.
+
+    >>> list(accumulate('abcde'))
+    ['a', 'ab', 'abc', 'abcd', 'abcde']
+    """
+    items_ = iter(increments)
+    try:
+        value = next(items_)
+    except StopIteration:
+        return
+    yield value
+    for item in items_:
+        value += item
+        yield value
